@@ -11,7 +11,7 @@ import shutil
 from jinja2 import Environment, FileSystemLoader
 import glob
 import pickle
-from src.unitgrade.unitgrade import Report
+from src.unitgrade.framework import Report
 from unitgrade_private import docker_helpers
 
 COURSES_BASE = "/home/tuhe/Autolab/courses/AutoPopulated"
