@@ -71,7 +71,7 @@ def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade
     return pycom, token_location
 
 
-def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, tag=None, instructor_grade_script=None):
+def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, tag=None, instructor_grade_script=None, fix_user=True):
     """
     This thingy works:
 
@@ -120,15 +120,19 @@ def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file,
     pycom = ".".join( sources['report_module_specification'][:-1] + [os.path.basename(gscript)[:-3],] )
     pycom = "python3 -m " + pycom
 
+    if fix_user:
+        user_cmd = ' --user "$(id -u):$(id -g)" '
+    else:
+        user_cmd = ''
     tmp_path = os.path.abspath(host_tmp_dir).replace("\\", "/")
-    dcom = f"docker run -v {tmp_path}:/home {dockname} {pycom}"
+    dcom = f"docker run {user_cmd} -v {tmp_path}:/home {dockname} {pycom}"
     cdcom = f"cd {os.path.dirname(Dockerfile_location)}"
     fcom = f"{cdcom}  && {dcom}"
     print("> Running docker command")
     print(fcom)
     init = time.time() - start
     # thtools.execute_command(fcom.split())
-    subprocess.check_output(fcom.split(), shell=True).decode("utf-8")
+    subprocess.check_output(fcom, shell=True).decode("utf-8")
     host_tmp_dir +"/" + os.path.dirname(tmp_grade_file) + "/"
     tokens = glob.glob( os.path.dirname(instructor_grade_script) + "/*.token" )
     for t in tokens:
